@@ -5,8 +5,8 @@ SCRIPT_DIR="$(cd "$(dirname "${BASH_SOURCE[0]}")" && pwd)"
 CRATE_DIR="${SCRIPT_DIR}/../"
 
 # freeze the spec version and generator version to make generation reproducible
-SPEC_VERSION=v1.8.0
-SEMCOVGEN_VERSION=0.8.0
+SPEC_VERSION=v1.17.0
+SEMCOVGEN_VERSION=0.15.1
 
 cd "$CRATE_DIR"
 
@@ -21,12 +21,12 @@ git reset --hard FETCH_HEAD
 cd "$CRATE_DIR"
 
 docker run --rm \
-	-v "${CRATE_DIR}/opentelemetry-specification/semantic_conventions/trace:/source" \
+	-v "${CRATE_DIR}/opentelemetry-specification/semantic_conventions:/source" \
 	-v "${CRATE_DIR}/scripts/templates:/templates" \
 	-v "${CRATE_DIR}/src:/output" \
 	otel/semconvgen:$SEMCOVGEN_VERSION \
-	--yaml-root /source \
-	code \
+  --exclude resource/** \
+  -f /source code \
 	--template /templates/semantic_attributes.rs.j2 \
 	--output /output/trace.rs \
 	--parameters conventions=trace
@@ -36,8 +36,7 @@ docker run --rm \
 	-v "${CRATE_DIR}/scripts/templates:/templates" \
 	-v "${CRATE_DIR}/src:/output" \
 	otel/semconvgen:$SEMCOVGEN_VERSION \
-	--yaml-root /source \
-	code \
+  -f /source code \
 	--template /templates/semantic_attributes.rs.j2 \
 	--output /output/resource.rs \
 	--parameters conventions=resource
